@@ -225,11 +225,19 @@ impl<P: Printer> PathWorker for RunWithInferredLang<P> {
     self.arg.input.walk()
   }
 
-  fn produce_item(&self, path: &Path) -> Option<Self::Item> {
+  fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
     let lang = SgLang::from_path(path)?;
     let matcher = self.arg.build_pattern(lang).ok()?;
-    let match_unit = filter_file_pattern(path, lang, matcher)?;
-    Some((match_unit, lang))
+    // match sub region
+    if let Some(sub_langs) = lang.injectable_sg_langs() {
+      let matchers = sub_langs.filter_map(|l| {
+        let pattern = self.arg.build_pattern(l).ok()?;
+        Some((l, pattern))
+      });
+      filter_file_pattern(path, lang, Some(matcher), matchers)
+    } else {
+      filter_file_pattern(path, lang, Some(matcher), std::iter::empty())
+    }
   }
 }
 
@@ -237,16 +245,23 @@ struct RunWithSpecificLang<Printer> {
   arg: RunArg,
   printer: Printer,
   pattern: Pattern<SgLang>,
+  rewrite: Option<Fixer<SgLang>>,
 }
 
 impl<Printer> RunWithSpecificLang<Printer> {
   fn new(arg: RunArg, printer: Printer) -> Result<Self> {
     let lang = arg.lang.ok_or(anyhow::anyhow!(EC::LanguageNotSpecified))?;
     let pattern = arg.build_pattern(lang)?;
+    let rewrite = if let Some(s) = &arg.rewrite {
+      Some(Fixer::from_str(s, &lang).context(EC::ParsePattern)?)
+    } else {
+      None
+    };
     Ok(Self {
       arg,
       printer,
       pattern,
+      rewrite,
     })
   }
 }
@@ -262,14 +277,9 @@ impl<P: Printer> Worker for RunWithSpecificLang<P> {
     if let Some(format) = arg.debug_query {
       format.debug_query(&self.arg.pattern, lang, self.arg.output.color);
     }
-    let rewrite = if let Some(s) = &arg.rewrite {
-      Some(Fixer::from_str(s, &lang).context(EC::ParsePattern)?)
-    } else {
-      None
-    };
     let mut has_matches = false;
     for match_unit in items {
-      match_one_file(printer, &match_unit, &rewrite)?;
+      match_one_file(printer, &match_unit, &self.rewrite)?;
       has_matches = true;
     }
     printer.after_print()?;
@@ -286,11 +296,17 @@ impl<P: Printer> PathWorker for RunWithSpecificLang<P> {
     let lang = self.arg.lang.expect("must present");
     self.arg.input.walk_lang(lang)
   }
-  fn produce_item(&self, path: &Path) -> Option<Self::Item> {
+  fn produce_item(&self, path: &Path) -> Option<Vec<Self::Item>> {
     let arg = &self.arg;
     let pattern = self.pattern.clone();
     let lang = arg.lang.expect("must present");
-    filter_file_pattern(path, lang, pattern)
+    let path_lang = SgLang::from_path(path)?;
+    let ret = if path_lang == lang {
+      filter_file_pattern(path, lang, Some(pattern), std::iter::empty())?
+    } else {
+      filter_file_pattern(path, path_lang, None, std::iter::once((lang, pattern)))?
+    };
+    Some(ret.into_iter().map(|n| n.0).collect())
   }
 }
 
@@ -367,6 +383,16 @@ mod test {
     assert!(run_with_pattern(arg).is_ok())
   }
 
+  #[test]
+  fn test_run_with_strictness() {
+    let arg = RunArg {
+      pattern: "console.log".to_string(),
+      strictness: Some(Strictness(MatchStrictness::Ast)),
+      ..default_run_arg()
+    };
+    assert!(run_with_pattern(arg).is_ok())
+  }
+
   #[test]
   fn test_run_with_specific_lang() {
     let arg = RunArg {
