@@ -26,11 +26,15 @@ mod rust;
 mod scala;
 mod swift;
 
-use ast_grep_core::language::TSLanguage;
+use html::Html;
+
+use ast_grep_core::language::{TSLanguage, TSRange};
 use ast_grep_core::meta_var::MetaVariable;
+use ast_grep_core::{Doc, Node};
 use ignore::types::{Types, TypesBuilder};
 use serde::{de, Deserialize, Deserializer, Serialize};
 use std::borrow::Cow;
+use std::collections::HashMap;
 use std::fmt;
 use std::fmt::{Display, Formatter};
 use std::iter::repeat;
@@ -114,9 +118,6 @@ impl_lang_expando!(Go, language_go, 'µ');
 // https://ghc.gitlab.haskell.org/ghc/doc/users_guide/exts/unicode_syntax.html
 // and the tree-sitter-haskell grammar parses it too.
 impl_lang_expando!(Haskell, language_haskell, 'µ');
-// tree-sitter-html uses locale dependent iswalnum for tagName
-// https://github.com/tree-sitter/tree-sitter-html/blob/b5d9758e22b4d3d25704b72526670759a9e4d195/src/scanner.c#L194
-impl_lang_expando!(Html, language_html, 'z');
 // https://github.com/fwcd/tree-sitter-kotlin/pull/93
 impl_lang_expando!(Kotlin, language_kotlin, 'µ');
 // we can use any char in unicode range [:XID_Start:]
@@ -313,6 +314,14 @@ impl Language for SupportLang {
   impl_lang_method!(meta_var_char, () => char);
   impl_lang_method!(expando_char, () => char);
   impl_lang_method!(extract_meta_var, (source: &str) => Option<MetaVariable>);
+  impl_lang_method!(injectable_languages, () => Option<&'static [&'static str]>);
+
+  fn extract_injections<D: Doc>(&self, root: Node<D>) -> HashMap<String, Vec<TSRange>> {
+    match self {
+      SupportLang::Html => Html.extract_injections(root),
+      _ => HashMap::new(),
+    }
+  }
 
   fn pre_process_pattern<'q>(&self, query: &'q str) -> Cow<'q, str> {
     execute_lang_method! { self, pre_process_pattern, query }
